@@ -1,5 +1,5 @@
-`print.itemFit` <-
-function (x, digits = 3, ...) {
+print.itemFit <-
+function (x, digits = 4, ...) {
     if (!inherits(x, "itemFit"))
         stop("Use only with 'itemFit' objects.\n")
     cat("\nItem-Fit Statistics and P-values\n")
@@ -10,8 +10,8 @@ function (x, digits = 3, ...) {
         cat("\nMonte Carlo samples:", x$B, "\n\n")
     else
         cat("\n\n")
-    pvals <- round(x$p.values, digits)
-    out.pvals <- sprintf(paste("%.", digits, "f", collapse = ""), pvals)
+    pvals <- round(x$p.values, digits = digits)
+    out.pvals <- formatC(pvals, digits = digits)
     out.pvals[pvals == 0] <- paste("< 0.", paste(rep(0, digits - 1), collapse = ""), "1", collapse = "", sep = "")
     print(data.frame("X^2" = round(x$Tobs, digits), "Pr(>X^2)" = out.pvals, row.names = names(x$Tobs), 
             check.names = FALSE))
